@@ -12,11 +12,11 @@ C<Math::Geometry::Construction::Derivate::IntersectionCircleLine> - circle line
 
 =head1 VERSION
 
-Version 0.014
+Version 0.017
 
 =cut
 
-our $VERSION = '0.014';
+our $VERSION = '0.017';
 
 
 ###########################################################################
@@ -84,6 +84,12 @@ sub positions {
 #                                                                         #
 ###########################################################################
 
+sub register_derived_point {
+    my ($self, $point) = @_;
+
+    foreach($self->input) { $_->register_point($point) }
+}
+
 1;
 
 
